Sphinx .Net Domain
==================


.. image:: https://readthedocs.org/projects/sphinxcontrib-dotnetdomain/badge/?version=latest
   :target: https://sphinxcontrib-dotnetdomain.readthedocs.org
   :alt: Documentation Status

.. image:: https://travis-ci.org/rtfd/sphinxcontrib-dotnetdomain.svg?branch=master
   :target: https://travis-ci.org/rtfd/sphinxcontrib-dotnetdomain

.. warning:: This is a pre-release version. Some or all features might not work yet.

This package provides a .Net domain for Sphinx documentation.

Full documentation can be found on `Read the Docs <http://sphinxcontrib-dotnetdomain.readthedocs.org>`_.

Contents
--------

.. toctree::
   :caption: Main
   :glob:
   :maxdepth: 2

   design

.. toctree::
   :caption: API
   :glob:
   :maxdepth: 2

   autoapi/index

